netapp_ontap.models.cluster_space_block_storage_medias API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_space_block_storage_medias`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterSpaceBlockStorageMediasSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterSpaceBlockStorageMedias object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `available: Size GET POST PATCH`

    Available space across the cluster based on media type.

  `efficiency: SpaceEfficiency GET POST PATCH`

    The efficiency field of the cluster_space_block_storage_medias.

  `efficiency_without_snapshots: SpaceEfficiency GET POST PATCH`

    The efficiency_without_snapshots field of the cluster_space_block_storage_medias.

  `efficiency_without_snapshots_flexclones: SpaceEfficiency GET POST PATCH`

    The efficiency_without_snapshots_flexclones field of the cluster_space_block_storage_medias.

  `physical_used: Size GET POST PATCH`

    Total physical used space across the cluster based on media type.

  `size: Size GET POST PATCH`

    Total space across the cluster based on media type.

  `type: str GET POST PATCH`

    The type of media being used.

    Valid choices:

    - hdd
    - hybrid
    - lun
    - ssd
    - vmdisk
  `used: Size GET POST PATCH`

    Used space across the cluster based on media type.